import numpy as np

def getPoslistNCube(shape,dtype=np.double):
	"""Create list of positions in an n-dimensional cube of size shape."""
	ndim=len(shape)

	axGrids=[np.arange(i,dtype=dtype) for i in shape]
	prePos=np.array(np.meshgrid(*axGrids,indexing='ij'),dtype=dtype )
	# the first dimension of prepos is the dimension of the  posvector, the successive dimensions are in the cube
	# so need to move first axis to end, and then flatten
	pos=np.rollaxis(prePos,0,ndim+1)
	# flattening
	newshape=(-1,ndim)
	return (pos.reshape(newshape)).copy()

def isInBox(x0,x1,y):
	"""Checks if the points in y are in the hypercube spanned by corners x0 and x1. (x0<=y<x1 to be precise.)
	Returns list of bool."""
	return np.logical_and( np.all(x0<=y,axis=1), np.all(y<=x1,axis=1) )
	
def GetFullPosArray(data,indices,indptr):
	"""In a standard sparse kernel rep, the indices only contain coords of axis [1,..,dim-1].
	This method returns a new indices array where the first axis is added. Useful for post-processing."""

	if indices.ndim==1:
		posDim=2
	else:
		posDim=indices.shape[1]+1
    
	newIndices=np.zeros((indices.shape[0],posDim),dtype=np.int32)

	newIndices[:,1:]=indices.reshape((indices.shape[0],posDim-1))
	for i in range(indptr.shape[0]-1):
		newIndices[indptr[i]:indptr[i+1],0]=i
    
	return newIndices
	
def GetBarycenterPoints(posArray,weightList,posList):
	posDim=posList[0].shape[1]
	result=np.zeros((posArray.shape[0],posDim),dtype=np.double)
	for i in range(len(weightList)):
		result[...]+=weightList[i]*posList[i][posArray[:,i]]
	return result
